@@ -158,25 +158,50 @@ def sanitize_protocol_message(message: str) -> str:
         return message
 
 
-class ProtocolLoggingStream:
+class ProtocolLoggingReceiveStream:
     """
-    MCPプロトコルメッセージをログに記録するストリームラッパー
+    MCPプロトコルメッセージをログに記録する受信ストリームラッパー
     """
 
-    def __init__(self, original_stream: Any, stream_type: str) -> None:
+    def __init__(self, original_stream: Any) -> None:
         self.original_stream = original_stream
-        self.stream_type = stream_type  # 'input' or 'output'
 
-    async def read(self, size: int = -1) -> bytes:
-        """読み取り操作をラップしてログに記録"""
+        if protocol_logger:
+            protocol_logger.debug(
+                f"PROTOCOL_RECEIVE_STREAM_INIT - original_stream_type: {type(original_stream)}"
+            )
+
+    async def receive(self) -> Any:
+        """受信操作をラップしてログに記録"""
         try:
-            data: bytes = await self.original_stream.read(size)
-            if data and self.stream_type == "input":
+            if protocol_logger:
+                protocol_logger.debug("RECEIVE_START - Waiting for message")
+
+            # 元のストリームのreceiveメソッドを呼び出し
+            data = await self.original_stream.receive()
+
+            if protocol_logger:
+                protocol_logger.debug(
+                    f"RECEIVE_COMPLETE - data_received: {data is not None}, data_type: {type(data)}"
+                )
+
+            if data is not None:
                 try:
                     if protocol_logger:
-                        message = data.decode("utf-8").strip()
-                        if message:
-                            sanitized_message = sanitize_protocol_message(message)
+                        # データがbytes型の場合はデコードしてログに記録
+                        if isinstance(data, bytes):
+                            message = data.decode("utf-8").strip()
+                            if message:
+                                sanitized_message = sanitize_protocol_message(message)
+                                protocol_logger.debug(f"REQUEST: {sanitized_message}")
+                            else:
+                                protocol_logger.debug(
+                                    "REQUEST_EMPTY - Empty message received"
+                                )
+                        else:
+                            # その他の型の場合は文字列化してログに記録
+                            message_str = str(data)
+                            sanitized_message = sanitize_protocol_message(message_str)
                             protocol_logger.debug(f"REQUEST: {sanitized_message}")
                 except Exception as e:
                     # protocol_loggerがNoneの場合でもエラーを出力しない
@@ -184,27 +209,78 @@ class ProtocolLoggingStream:
                         protocol_logger.error(f"Error logging request: {e}")
             return data
         except Exception as e:
-            # 元のストリームのエラーをそのまま伝播
+            # 詳細なエラー情報をログに記録
+            if protocol_logger:
+                import traceback
+
+                protocol_logger.error(
+                    f"RECEIVE_ERROR - error: {e}, traceback: {traceback.format_exc()}"
+                )
             raise e
 
-    async def write(self, data: bytes) -> None:
-        """書き込み操作をラップしてログに記録"""
+    def __getattr__(self, name: str) -> Any:
+        """他のメソッドは元のストリームに委譲"""
+        return getattr(self.original_stream, name)
+
+
+class ProtocolLoggingSendStream:
+    """
+    MCPプロトコルメッセージをログに記録する送信ストリームラッパー
+    """
+
+    def __init__(self, original_stream: Any) -> None:
+        self.original_stream = original_stream
+
+        if protocol_logger:
+            protocol_logger.debug(
+                f"PROTOCOL_SEND_STREAM_INIT - original_stream_type: {type(original_stream)}"
+            )
+
+    async def send(self, item: Any) -> None:
+        """送信操作をラップしてログに記録"""
         try:
-            if data and self.stream_type == "output":
+            if protocol_logger:
+                protocol_logger.debug(
+                    f"SEND_START - item_type: {type(item)}, item_not_none: {item is not None}"
+                )
+
+            if item is not None:
                 try:
                     if protocol_logger:
-                        message = data.decode("utf-8").strip()
-                        if message:
-                            sanitized_message = sanitize_protocol_message(message)
+                        # データがbytes型の場合はデコードしてログに記録
+                        if isinstance(item, bytes):
+                            message = item.decode("utf-8").strip()
+                            if message:
+                                sanitized_message = sanitize_protocol_message(message)
+                                protocol_logger.debug(f"RESPONSE: {sanitized_message}")
+                            else:
+                                protocol_logger.debug(
+                                    "RESPONSE_EMPTY - Empty message to send"
+                                )
+                        else:
+                            # その他の型の場合は文字列化してログに記録
+                            message_str = str(item)
+                            sanitized_message = sanitize_protocol_message(message_str)
                             protocol_logger.debug(f"RESPONSE: {sanitized_message}")
                 except Exception as e:
                     # protocol_loggerがNoneの場合でもエラーを出力しない
                     if protocol_logger:
                         protocol_logger.error(f"Error logging response: {e}")
 
-            await self.original_stream.write(data)
+            # 元のストリームのsendメソッドを呼び出し
+            await self.original_stream.send(item)
+
+            if protocol_logger:
+                protocol_logger.debug("SEND_COMPLETE - Message sent successfully")
+
         except Exception as e:
-            # 元のストリームのエラーをそのまま伝播
+            # 詳細なエラー情報をログに記録
+            if protocol_logger:
+                import traceback
+
+                protocol_logger.error(
+                    f"SEND_ERROR - error: {e}, traceback: {traceback.format_exc()}"
+                )
             raise e
 
     def __getattr__(self, name: str) -> Any:
@@ -225,9 +301,15 @@ async def protocol_logging_server(
     Returns:
         ラップされたストリームのタプル
     """
+    if protocol_logger:
+        protocol_logger.debug("PROTOCOL_LOGGING_SERVER - Starting stream wrapping")
+
     # 入出力ストリームをラップ
-    wrapped_read_stream = ProtocolLoggingStream(read_stream, "input")
-    wrapped_write_stream = ProtocolLoggingStream(write_stream, "output")
+    wrapped_read_stream = ProtocolLoggingReceiveStream(read_stream)
+    wrapped_write_stream = ProtocolLoggingSendStream(write_stream)
+
+    if protocol_logger:
+        protocol_logger.debug("PROTOCOL_LOGGING_SERVER - Stream wrapping completed")
 
     return wrapped_read_stream, wrapped_write_stream
 
@@ -435,15 +517,43 @@ async def main() -> None:
     logger.info("Starting PostgreSQL MCP Server...")
     protocol_logger.info("MCP Protocol logging started")
 
-    async with stdio_server() as (read_stream, write_stream):
-        # プロトコルロギングを有効化
-        read_stream, write_stream = await protocol_logging_server(
-            read_stream, write_stream
-        )
+    try:
+        async with stdio_server() as (read_stream, write_stream):
+            if protocol_logger:
+                protocol_logger.debug(
+                    "STDIO_SERVER - stdio_server context entered successfully"
+                )
 
-        await server.run(
-            read_stream, write_stream, server.create_initialization_options()
-        )
+            # プロトコルロギングを有効化
+            read_stream, write_stream = await protocol_logging_server(
+                read_stream, write_stream
+            )
+
+            if protocol_logger:
+                protocol_logger.debug("SERVER_RUN - Starting server.run()")
+
+            await server.run(
+                read_stream, write_stream, server.create_initialization_options()
+            )
+
+            if protocol_logger:
+                protocol_logger.debug("SERVER_RUN - server.run() completed normally")
+
+    except Exception as e:
+        if protocol_logger:
+            import traceback
+
+            protocol_logger.error(
+                f"SERVER_ERROR - Exception in main server loop: {e}, traceback: {traceback.format_exc()}"
+            )
+        logger.error(f"Server error: {e}")
+        import traceback
+
+        logger.error(f"Server error traceback: {traceback.format_exc()}")
+        # 詳細なエラー情報を標準エラー出力にも出力
+        print(f"Server error: {e}", file=sys.stderr)
+        print(f"Server error traceback: {traceback.format_exc()}", file=sys.stderr)
+        raise
 
 
 def cli_main() -> None:
